using WebApp04.Data;
using Microsoft.EntityFrameworkCore;
using WebApp04.Models;

namespace WebApp04
{
    public class Program
    {
        public static void PopulateDB()
        {
            IConfiguration config = new ConfigurationBuilder()
                .AddJsonFile("appsettings.json")
                .Build();

            var options = new DbContextOptionsBuilder<GoodWebContext>()
                .UseSqlite(config.GetConnectionString("Default"))
                .Options;

            using (var context = new GoodWebContext(options))
            {
                context.Database.EnsureCreated();
                context.Database.Migrate();

                var cnt = new Contact();

                context.Contacts.Add(cnt);
                context.SaveChanges();
            }
        }


        public static void Main(string[] args)
        {
            ///
            PopulateDB();
            ///

            var builder = WebApplication.CreateBuilder(args);

            // Add services to the container.
            builder.Services.AddRazorPages();
            
            
            builder.Services.AddSqlite<GoodWebContext>(
                builder.Configuration.GetConnectionString("Default"));


            var app = builder.Build();

            // Configure the HTTP request pipeline.
            if (!app.Environment.IsDevelopment())
            {
                app.UseExceptionHandler("/Error");
            }
            app.UseStaticFiles();

            app.UseRouting();

            app.UseAuthorization();

            app.MapRazorPages();

            app.Run();
        }
    }
}